@@ -1,8 +1,6 @@
 # -*- coding: latin-1 -*-
-url="ns244.evxonline.net" #Temporary Folder
+url="morphonet.org" 
 port=8000
-vt_path="Librairies/vt"
-#url="morphonet.org"
 #url="localhost" #For DB installed in local
     
 
