@@ -1,5 +1,5 @@
 
-def getBorders(data,cellCoords,border=4):
+def get_borders(data,cellCoords,border=4):
     xmin=max(0,cellCoords[0].min()-border)
     xmax=min(data.shape[0],cellCoords[0].max()+border)
     ymin=max(0,cellCoords[1].min()-border)
@@ -9,7 +9,7 @@ def getBorders(data,cellCoords,border=4):
     return xmin,xmax,ymin,ymax,zmin,zmax
 
 
-def applyNewLabel(data,xmin,ymin,zmin,labelw):
+def apply_new_label(data,xmin,ymin,zmin,labelw,minVol=0):
     import numpy as np
     labels=np.unique(labelw)
     labels=labels[labels!=0] #Remove Background
@@ -25,11 +25,15 @@ def applyNewLabel(data,xmin,ymin,zmin,labelw):
             BigestL=l
 
     labels=labels[labels!=BigestL]
-    lastID=data.max()
-    lastID=lastID+1
+    newIds=[]
+    lastID=data.max()+1
     for l in labels:
         new_coords=np.where(labelw==l)
-        data[new_coords[0]+xmin,new_coords[1]+ymin,new_coords[2]+zmin]=lastID
-        print('     ----->>>>>  Create a new ID '+str(lastID)+ " with "+str(len(new_coords[0]))+ " pixels")
-        lastID+=1
-    return data
+        if len(new_coords[0])>=minVol:
+            data[new_coords[0]+xmin,new_coords[1]+ymin,new_coords[2]+zmin]=lastID
+            print('     ----->>>>>  Create a new object '+str(lastID)+ " with "+str(len(new_coords[0]))+ " voxels")
+            lastID+=1
+            newIds.append(lastID)
+        else:
+            print("     ----->>>>>  Do not create with "+str(len(new_coords[0]))+ " voxels")
+    return data,newIds
